==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Http/TwigResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_f73dab606630b388645c4f7d" . "3fbb13bb" => base64_decode("YXJyYXlfb" . "WVyZ2U="));




class TwigResponse
{
    
    
    
    
    
    
    protected $template;
    
    
    
    
    
    
    protected $arguments;
    
    
    
    
    protected $http_status;
    
    
    
    
    protected $http_headers;
    
    
    
    
    
    
    
    public function __construct(string $template, array $arguments = [])
    {
        $this->setTemplate($template);
        $this->setArguments($arguments);
        $this->setHttpStatus(200);
        $this->setHttpHeaders([]);
    }
    
    
    
    
    
    
    public function getTemplate() : string
    {
        return $this->template;
    }
    
    
    
    
    
    
    public function setTemplate(string $template) : void
    {
        $this->template = $template;
    }
    
    
    
    
    
    
    public function getArguments() : array
    {
        return $this->arguments;
    }
    
    
    
    
    
    
    public function setArguments(array $arguments) : void
    {
        $this->arguments = $arguments;
    }
    
    
    
    
    
    
    public function addArguments(array $arguments) : void
    {
        $this->arguments = $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f73dab606630b388645c4f7d3fbb1" . "3bb"]($this->arguments, $arguments);
    }
    
    
    
    
    
    
    public function getHttpStatus() : int
    {
        return $this->http_status;
    }
    
    
    
    
    
    
    
    public function setHttpStatus(int $_5cbbc47250bb0d1ba94516fec2c7033c) : void
    {
        $this->http_status = $_5cbbc47250bb0d1ba94516fec2c7033c;
    }
    
    
    
    
    
    
    public function getHttpHeaders() : array
    {
        return $this->http_headers;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function setHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $_bb832a060044346957089d9d9adaa8dd;
    }
    
    
    
    
    
    
    public function addHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_f73dab606630b388645c4f" . "7d3fbb13bb"]($this->http_headers, $_bb832a060044346957089d9d9adaa8dd);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Http/TwigResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_f73dab606630b388645c4f7d3fbb13b" . "b" => base64_decode("YXJyYXl" . "fbWVyZ2" . "U="));




class TwigResponse
{
    
    
    
    
    
    
    protected $template;
    
    
    
    
    
    
    protected $arguments;
    
    
    
    
    protected $http_status;
    
    
    
    
    protected $http_headers;
    
    
    
    
    
    
    
    public function __construct(string $template, array $arguments = [])
    {
        $this->setTemplate($template);
        $this->setArguments($arguments);
        $this->setHttpStatus(200);
        $this->setHttpHeaders([]);
    }
    
    
    
    
    
    
    public function getTemplate() : string
    {
        return $this->template;
    }
    
    
    
    
    
    
    public function setTemplate(string $template) : void
    {
        $this->template = $template;
    }
    
    
    
    
    
    
    public function getArguments() : array
    {
        return $this->arguments;
    }
    
    
    
    
    
    
    public function setArguments(array $arguments) : void
    {
        $this->arguments = $arguments;
    }
    
    
    
    
    
    
    public function addArguments(array $arguments) : void
    {
        $this->arguments = $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_f73dab606630b388645c4f7" . "d3fbb13bb"]($this->arguments, $arguments);
    }
    
    
    
    
    
    
    public function getHttpStatus() : int
    {
        return $this->http_status;
    }
    
    
    
    
    
    
    
    public function setHttpStatus(int $_5cbbc47250bb0d1ba94516fec2c7033c) : void
    {
        $this->http_status = $_5cbbc47250bb0d1ba94516fec2c7033c;
    }
    
    
    
    
    
    
    public function getHttpHeaders() : array
    {
        return $this->http_headers;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function setHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $_bb832a060044346957089d9d9adaa8dd;
    }
    
    
    
    
    
    
    public function addHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f73dab606630b388645c4f" . "7d3fbb13bb"]($this->http_headers, $_bb832a060044346957089d9d9adaa8dd);
    }
}
